﻿using System.Collections.ObjectModel;
using System.Device.Location;
using System.Linq;
using GalaSoft.MvvmLight;
using Microsoft.Phone.Maps.Services;

namespace TapReverseGeocode.Logic.ViewModels
{
  public class MapViewModel : ViewModelBase
  {
    public MapViewModel()
    {
      Addresses = new ObservableCollection<string>();
    }

    private GeoCoordinate tapCoordinate;
    public GeoCoordinate TapCoordinate
    {
      get { return tapCoordinate; }
      set
      {
        tapCoordinate = value;
        RaisePropertyChanged(() => TapCoordinate);
        StartReverseGeoCoding();
      }
    }

    public ObservableCollection<string> Addresses { get; set; }

    private void StartReverseGeoCoding()
    {
      var reverseGeocode = new ReverseGeocodeQuery();
      reverseGeocode.GeoCoordinate = new GeoCoordinate(TapCoordinate.Latitude, TapCoordinate.Longitude);
      reverseGeocode.QueryCompleted += ReverseGeocodeQueryCompleted;
      reverseGeocode.QueryAsync();
    }

    private void ReverseGeocodeQueryCompleted(object sender, 
      QueryCompletedEventArgs<System.Collections.Generic.IList<MapLocation>> e)
    {
      var reverseGeocode = sender as ReverseGeocodeQuery;
      if (reverseGeocode != null)
      {
        reverseGeocode.QueryCompleted -= ReverseGeocodeQueryCompleted;
      }
      Addresses.Clear();
      if (!e.Cancelled)
      {
        foreach (var adress in e.Result.Select(adrInfo => adrInfo.Information.Address))
        {
          Addresses.Add(string.Format("{0} {1} {2} {3} {4}", 
            adress.Street, adress.HouseNumber, adress.PostalCode,
            adress.City,adress.Country).Trim());
        }
      }
    }
  }
}
